pub struct CreateGlobalChatInputCommand<'a> { /* private fields */ }
Create a new chat input global command.

The description must be between 1 and 100 characters in length. Creating a command with the same name as an already-existing global command will overwrite the old command. See Discord Docs/Create Global Application Command.

Implementations

Add a list of command options.

Required command options must be added before optional options.

Errors

Returns an error of type OptionsRequiredFirst if a required option was added after an optional option. The problem option’s index is provided.

Default permissions required for a member to run the command.

Defaults to None.

Set whether the command is available in DMs.

Defaults to None.

Set the localization dictionary for the command description.

Defaults to None.

Errors

Returns an error of type DescriptionInvalid if the description is invalid.

Set the localization dictionary for the command name.

Defaults to None.

Errors

Returns an error of type NameLengthInvalid if the length is invalid.

Returns an error of type NameCharacterInvalid if the name contains a non-alphanumeric character or an uppercase character for which a lowercase variant exists.

Set whether the command is age-restricted.

Defaults to not being specified, which uses Discord’s default.

👎Deprecated since 0.14.0: use .await or into_future instead

Execute the request, returning a future resolving to a Response.