pub struct CreateGuildUserCommand<'a> { /* private fields */ }
Create a user command in a guild.

Creating a guild command with the same name as an already-existing guild command in the same guild will overwrite the old command. See Discord Docs/Create Guild Application Command.

Implementations

Default permissions required for a member to run the command.

Defaults to None.

Set the localization dictionary for the command name.

Defaults to None.

Errors

Returns an error of type NameLengthInvalid if the name is invalid.

Set whether the command is age-restricted.

Defaults to not being specified, which uses Discord’s default.

👎Deprecated since 0.14.0: use .await or into_future instead

Execute the request, returning a future resolving to a Response.