Struct twilight_http::request::channel::stage::CreateStageInstance
source · pub struct CreateStageInstance<'a> { /* private fields */ }Expand description
Create a new stage instance associated with a stage channel.
Requires the user to be a moderator of the stage channel.
Implementations
sourceimpl<'a> CreateStageInstance<'a>
impl<'a> CreateStageInstance<'a>
sourcepub const fn privacy_level(self, privacy_level: PrivacyLevel) -> Self
pub const fn privacy_level(self, privacy_level: PrivacyLevel) -> Self
Set the PrivacyLevel of the instance.
sourcepub const fn send_start_notification(self, send_start_notification: bool) -> Self
pub const fn send_start_notification(self, send_start_notification: bool) -> Self
Set whether to notify everyone when a stage starts.
The stage moderator must have Permissions::MENTION_EVERYONE for this
notification to be sent.
sourcepub fn exec(self) -> ResponseFuture<StageInstance> ⓘ
👎Deprecated since 0.14.0: use .await or into_future instead
pub fn exec(self) -> ResponseFuture<StageInstance> ⓘ
.await or into_future insteadExecute the request, returning a future resolving to a Response.