Struct twilight_http::request::channel::stage::GetStageInstance
source · pub struct GetStageInstance<'a> { /* private fields */ }Expand description
Gets the stage instance associated with a stage channel, if it exists.
Implementations
sourceimpl<'a> GetStageInstance<'a>
impl<'a> GetStageInstance<'a>
sourcepub fn exec(self) -> ResponseFuture<StageInstance> ⓘ
👎Deprecated since 0.14.0: use .await or into_future instead
pub fn exec(self) -> ResponseFuture<StageInstance> ⓘ
.await or into_future insteadExecute the request, returning a future resolving to a Response.