pub struct CreateBan<'a> { /* private fields */ }
Bans a user from a guild, optionally with the number of days’ worth of messages to delete and the reason.

Examples

Ban user 200 from guild 100, deleting 1 day’s (86_400 second’s) worth of messages, for the reason "memes":

use twilight_http::{request::AuditLogReason, Client};
use twilight_model::id::Id;

let client = Client::new("my token".to_owned());

let guild_id = Id::new(100);
let user_id = Id::new(200);
client
    .create_ban(guild_id, user_id)
    .delete_message_seconds(86_400)?
    .reason("memes")?
    .await?;

Implementations

Set the number of seconds’ worth of messages to delete.

The number of seconds must be less than or equal to 604_800 (this is equivalent to 7 days).

Errors

Returns an error of type CreateGuildBanDeleteMessageSeconds if the number of seconds is greater than 604_800 (this is equivalent to 7 days).

👎Deprecated since 0.14.0: use .await or into_future instead

Execute the request, returning a future resolving to a Response.