Struct twilight_http::request::guild::create_guild::CategoryFieldsError [−][src]
pub struct CategoryFieldsError { /* fields omitted */ }Expand description
Error creating category fields.
Implementations
#[must_use = "retrieving the type has no effect if left unused"]pub const fn kind(&self) -> &CategoryFieldsErrorType[src]
#[must_use = "retrieving the type has no effect if left unused"]pub const fn kind(&self) -> &CategoryFieldsErrorType[src]Immutable reference to the type of error that occurred.
Consume the error, returning the source error if there is any.
#[must_use = "consuming the error into its parts has no effect if left unused"]pub fn into_parts(
self
) -> (CategoryFieldsErrorType, Option<Box<dyn Error + Send + Sync>>)[src]
#[must_use = "consuming the error into its parts has no effect if left unused"]pub fn into_parts(
self
) -> (CategoryFieldsErrorType, Option<Box<dyn Error + Send + Sync>>)[src]Consume the error, returning the owned error type and the source error.