pub struct RoleFieldsBuilder(_);
A builder for role fields.

Implementations

The maximum accepted color value.

This is used by color.

Create a new default role field builder.

Build the role fields.

Set the role color.

This must be a valid hexadecimal RGB value. 0x000000 is ignored and doesn’t count towards the final computed color in the user list. Refer to Self::COLOR_MAXIMUM for the maximum acceptable value.

Errors

Returns a RoleFieldsErrorType::ColorNotRgb error type if the color is not valid RGB.

Show the role above other roles in the user list.

Set the id of the role.

Errors

Returns a RoleFieldsErrorType::IdInvalid error type if the ID is set to 1.

Allow the role to be @mentioned.

Set the permissions of the role.

Set the position of the role.