pub struct TextFieldsBuilder(_);
A builder for text fields.

Implementations

The minimum number of UTF-16 code points that can be in a channel name.

This is used by new.

The maximum number of UTF-16 code points that can be in a channel name.

This is used by new.

The maximum length of a rate limit.

This is used by rate_limit_per_user.

The maximum number of UTF-16 code points that can be in a channel topic.

This is used by topic.

Create a new text fields builder.

Errors

Returns a TextFieldsErrorType::NameTooShort error type if the name is too short.

Returns a TextFieldsErrorType::NameTooLong error type if the name is too long.

Build the text fields.

Make the channel NSFW.

Set the channel’s permission overwrites.

Set the channel’s rate limit per user.

Errors

Returns a TextFieldsErrorType::RateLimitInvalid error type if the rate limit is invalid.

Set the channel’s topic.

Errors

Returns a TextFieldsErrorType::TopicTooLong error type if the topic is too long.