pub struct VoiceFieldsBuilder(_);
A builder for voice fields.

Implementations

The minimum number of UTF-16 code points that can be in a channel name.

This is used by new.

The maximum number of UTF-16 code points that can be in a channel name.

This is used by new.

Create a new voice fields builder.

Errors

Returns a VoiceFieldsErrorType::NameTooShort error type if the name is too short.

Returns a VoiceFieldsErrorType::NameTooLong error type if the name is too long.

Build the voice fields.

Set the voice channel’s bitrate.

Set the channel’s permission overwrites.

Set the voice channel’s user limit.