[−][src]Module twilight_http::request::guild::create_guild_channel
Structs
| CreateGuildChannel | Create a new request to create a guild channel. |
Enums
| CreateGuildChannelError | Returned when the channel can not be created as configured. |