Struct twilight_http::request::guild::role::UpdateRole
source · pub struct UpdateRole<'a> { /* private fields */ }Expand description
Update a role by guild id and its id.
Implementations
sourceimpl<'a> UpdateRole<'a>
impl<'a> UpdateRole<'a>
sourcepub const fn color(self, color: Option<u32>) -> Self
pub const fn color(self, color: Option<u32>) -> Self
Set the role color.
This must be a valid hexadecimal RGB value. 0x000000 is ignored and
doesn’t count towards the final computed color in the user list. Refer
to COLOR_MAXIMUM for the maximum acceptable value.
sourcepub const fn icon(self, icon: &'a [u8]) -> Self
pub const fn icon(self, icon: &'a [u8]) -> Self
Set the icon of the role.
Only works if the guild has the ROLE_ICONS feature.
sourcepub const fn mentionable(self, mentionable: bool) -> Self
pub const fn mentionable(self, mentionable: bool) -> Self
If true, the role can be @mentioned (pinged) in chat.
sourcepub const fn permissions(self, permissions: Permissions) -> Self
pub const fn permissions(self, permissions: Permissions) -> Self
Set the allowed permissions of this role.
sourcepub const fn unicode_emoji(self, unicode_emoji: &'a str) -> Self
pub const fn unicode_emoji(self, unicode_emoji: &'a str) -> Self
Set the unicode emoji of a role.