Struct twilight_http::request::guild::update_guild::UpdateGuildError [−][src]
pub struct UpdateGuildError { /* fields omitted */ }Expand description
The error returned when the guild can not be updated as configured.
Implementations
#[must_use = "retrieving the type has no effect if left unused"]pub const fn kind(&self) -> &UpdateGuildErrorType[src]
#[must_use = "retrieving the type has no effect if left unused"]pub const fn kind(&self) -> &UpdateGuildErrorType[src]Immutable reference to the type of error that occurred.
Consume the error, returning the source error if there is any.
#[must_use = "consuming the error into its parts has no effect if left unused"]pub fn into_parts(
self
) -> (UpdateGuildErrorType, Option<Box<dyn Error + Send + Sync>>)[src]
#[must_use = "consuming the error into its parts has no effect if left unused"]pub fn into_parts(
self
) -> (UpdateGuildErrorType, Option<Box<dyn Error + Send + Sync>>)[src]Consume the error, returning the owned error type and the source error.