Module twilight_http::request::template::create_template[][src]

Structs

CreateTemplate

Create a template from the current state of the guild.

CreateTemplateError

Error returned when the template can not be created as configured.

Enums

CreateTemplateErrorType

Type of CreateTemplateError that occurred.