pub struct CreateTemplate<'a> { /* private fields */ }
Create a template from the current state of the guild.

Requires the MANAGE_GUILD permission. The name must be at least 1 and at most 100 characters in length.

Errors

Returns an error of type TemplateName if the name length is too short or too long.

Implementations

Set the template’s description.

This must be less than or equal to 120 characters in length.

Errors

Returns an error of type TemplateDescription if the name length is too short or too long.

👎Deprecated since 0.14.0: use .await or into_future instead

Execute the request, returning a future resolving to a Response.