Re-exports

pub use self::execute_webhook::ExecuteWebhook;
pub use self::update_webhook_message::UpdateWebhookMessage;

Modules

Update a message created by a webhook via execution.

Structs

Create a webhook in a channel.
Delete a webhook by its ID.
Delete a message created by a webhook.
Execute a webhook, sending a message to its channel, and then wait for the message to be created.
Get all the webhooks of a channel.
Get a webhook by ID.
Get a webhook message by webhook ID, token, and message ID.
Update a webhook by ID.
Update a webhook, with a token, by ID.