[−][src]Module twilight_http::request::channel::webhook
Re-exports
pub use self::update_webhook_message::UpdateWebhookMessage; |
Modules
| update_webhook_message | Update a message created by a webhook via execution. |
Structs
| CreateWebhook | Create a webhook in a channel. |
| DeleteWebhook | Delete a webhook by its ID. |
| DeleteWebhookMessage | Delete a message created by a webhook. |
| ExecuteWebhook | Executes a webhook, sending a message to its channel. |
| GetChannelWebhooks | Get all the webhooks of a channel. |
| GetWebhook | Get a webhook by ID. |
| UpdateWebhook | Update a webhook by ID. |
| UpdateWebhookWithToken | Update a webhook, with a token, by ID. |