Module twilight_http::request::guild::create_guild
source · Structs
Category channel fields sent to Discord.
A builder for a category channel, and its children.
Error creating category fields.
Create a new request to create a guild.
The error returned when the guild can not be created as configured.
A builder for a list of channels.
Role fields sent to Discord.
A builder for role fields.
Error building role fields.
Text channel fields sent to Discord.
A builder for text fields.
Error building text fields.
Voice channel fields sent to Discord.
A builder for voice fields.
Error building voice fields.
Enums
Type of
CategoryFieldsError that occurred.Type of
CreateGuildError that occurred.Variants of channel fields sent to Discord.
Type of
RoleFieldsError that occurred.Type of
TextFieldsError that occurred.Type of
VoiceFieldsError that occurred.