Struct twilight_http::request::Request [−][src]
pub struct Request {
pub body: Option<Vec<u8>>,
pub form: Option<Form>,
pub headers: Option<HeaderMap<HeaderValue>>,
pub method: Method,
pub path: Path,
pub path_str: Cow<'static, str>,
// some fields omitted
}Fields
body: Option<Vec<u8>>The body of the request, if any.
form: Option<Form>The multipart form of the request, if any.
headers: Option<HeaderMap<HeaderValue>>The headers to set in the request, if any.
method: MethodThe method of the request.
path: PathThe ratelimiting bucket path.
path_str: Cow<'static, str>The URI path to request.
Implementations
pub fn new(
body: Option<Vec<u8>>,
headers: Option<HeaderMap<HeaderValue>>,
route: Route
) -> Self[src]👎 Deprecated since 0.4.0: Use Request::builder instead
pub fn new(
body: Option<Vec<u8>>,
headers: Option<HeaderMap<HeaderValue>>,
route: Route
) -> Self[src]👎 Deprecated since 0.4.0:
Use Request::builder instead
Create a simple Request with basic information.
Use the RequestBuilder if you need to set a combination of
configurations in the request.
Create a new request builder.
Examples
Create a request to create a message with a content of “test” in a channel with an ID of 1:
use twilight_http::{request::Request, routing::Route}; let body = br#"{ "content": "test" }"#.to_vec(); let request = Request::builder(Route::CreateMessage { channel_id: 1, }).body(body).build();
Create a request from only its route information.
If you need to set additional configurations like the body then use
builder.
Examples
Create a request to get a message with an ID of 2 in a channel with an ID of 1:
use twilight_http::{request::Request, routing::Route}; let request = Request::from_route(Route::GetMessage { channel_id: 1, message_id: 2, });
Whether to use the client’s authorization token in the request.