Module twilight_http::request::template [−][src]
Re-exports
pub use self::create_guild_from_template::CreateGuildFromTemplate; | |
pub use self::create_template::CreateTemplate; | |
pub use self::update_template::UpdateTemplate; |
Modules
| create_guild_from_template | |
| create_template | |
| update_template |
Structs
| DeleteTemplate | Delete a template by ID and code. |
| GetTemplate | Get a template by its code. |
| GetTemplates | Get a list of templates in a guild, by ID. |
| SyncTemplate | Sync a template to the current state of the guild, by ID and code. |